protocol

package
v1.26.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 18, 2026 License: MIT Imports: 8 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func InjectTraceAndRequestID

func InjectTraceAndRequestID(ctx context.Context, header http.Header) http.Header

InjectTraceAndRequestID injects trace context and request id headers. Trace headers are injected from ctx and will overwrite an existing traceparent when span context is valid.

Types

type HttpClientConfig

type HttpClientConfig struct {
	Module   string        `yaml:"module"`
	Host     string        `yaml:"host"`
	Timeout  time.Duration `yaml:"timeout"`
	MaxRetry int           `yaml:"max_retry"`
}

type SSEClientConfig

type SSEClientConfig struct {
	Module        string        `yaml:"service"`
	Host          string        `yaml:"host"`
	RetryWaitTime time.Duration `yaml:"retry_timeout"`
	MaxRetry      int           `yaml:"max_retry"`
}

Directories

Path Synopsis

Jump to